@@ -13,13 +13,11 @@ class OrderController
 
     public function __construct($pluginDirectoryPath, $pluginDirectoryURL)
     {
-
         $this->pluginDirectoryPath = $pluginDirectoryPath;
         $this->pluginDirectoryURL = $pluginDirectoryURL;
 
         $this->registerActions();
         $this->registerFilters();
-
     }
 
     private function registerActions()
@@ -81,7 +79,6 @@ class OrderController
                 'callback' => [$this, 'getAllOrdersForPrint'],
             ]);
         });
-
     }
 
     private function registerFilters()
@@ -91,21 +88,52 @@ class OrderController
 
     public static function getOrders($orderTypes)
     {
-        if (class_exists('WC_Order_Query')) {
-            $query = new \WC_Order_Query([
-                'limit' => -1,
-                'orderby' => 'date',
-                'order' => 'ASC',
-            ]);
-            $orders = $query->get_orders();
-
-        }
-
         if ($orderTypes == 'currentOrders') {
+            if (class_exists('WC_Order_Query')) {
+                $query = new \WC_Order_Query([
+                    'limit' => -1,
+                    'orderby' => 'date',
+                    'order' => 'ASC',
+                    'status' => ['wc-processing', 'wc-awaiting', 'wc-order-started', 'wc-being-collated', 'wc-ready', 'wc-datechanged', 'wc-readyfordelivery']
+                    //'status' => ['wc-processing', 'wc-awaiting', 'wc-order-started', 'wc-being-collated', 'wc-ready', 'wc-collected', 'wc-cancelled', 'wc-notcollected', 'wc-datechanged', 'wc-readyfordelivery']
+                ]);
+                $orders = $query->get_orders();
+            }
+
             $orderData = self::getOrderDataAsJson($orders);
         } else {
-            $orderData = self::getPastOrderDataAsJson($orders);
+            $dateTwoWeeksAgo = date('Y-m-d', strtotime("-2 weeks"));
+            $dateToday = date("Y-m-d");
 
+            function displayDates($date1, $date2, $format = 'Y-m-d')
+            {
+                $dates = [];
+                $current = strtotime($date1);
+                $date2 = strtotime($date2);
+                $stepVal = '+1 day';
+                while ($current <= $date2) {
+                    $dates[] = date($format, $current);
+                    $current = strtotime($stepVal, $current);
+                }
+                return $dates;
+            }
+
+            $dates = displayDates($dateTwoWeeksAgo, $dateToday);
+
+            global $wpdb;
+            $wooOrders = [];
+
+            foreach ($dates as $date) {
+                $getOrdersSQL = 'SELECT id FROM pex_simonhowie_posts WHERE id IN (SELECT order_id FROM pex_simonhowie_woocommerce_order_items WHERE order_item_id IN (SELECT order_item_id FROM pex_simonhowie_woocommerce_order_itemmeta WHERE meta_key = "_pickup_date" AND meta_value = "'. $date .'"))';
+                
+                $resultsGetOrders = $wpdb->get_results($getOrdersSQL);
+
+                foreach ($resultsGetOrders as $wooOrder) {
+                    array_push($wooOrders, wc_get_order($wooOrder->id));
+                }
+            }
+
+            $orderData = self::getPastOrderDataAsJson($wooOrders);
         }
 
         return $orderData;
@@ -115,7 +143,6 @@ class OrderController
     {
         $days = [];
         foreach ($orders as $singleOrder) {
-
             if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
                 $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
                 $pickupDate = strtotime($pickupDate);
@@ -124,7 +151,6 @@ class OrderController
                 $order = new Order($singleOrder);
 
                 if ($order->getOrderStatus() != "6" && $order->getOrderStatus() != "7" && $order->getOrderStatus() != "8") {
-
                     if (!isset($days[$pickupDate])) {
                         $days[$pickupDate] = [
                             'date' => $newDate,
@@ -147,22 +173,23 @@ class OrderController
      */
     public static function getShippingDetails($order)
     {
-
         $shippingDataArray = [];
-        foreach ($order->get_items('shipping') as $itemId => $shippingObject) {
-            $shippingData = $shippingObject->get_data();
-            foreach ($shippingData['meta_data'] as $singleShippingData) {
-                $singleShippingData = $singleShippingData->get_data();
-                switch ($singleShippingData['key']) {
-                    case '_pickup_location_name':
-                        $shippingDataArray['Pickup Location'] = $singleShippingData['value'];
-                        break;
-                    case '_pickup_date':
-                        $shippingDataArray['Pickup Date'] = $singleShippingData['value'];
-                        break;
-                    case '_pickup_location_address':
-                        $shippingDataArray['Pickup address'] = $singleShippingData['value'];
-                        break;
+        if ($order) {
+            foreach ($order->get_items('shipping') as $itemId => $shippingObject) {
+                $shippingData = $shippingObject->get_data();
+                foreach ($shippingData['meta_data'] as $singleShippingData) {
+                    $singleShippingData = $singleShippingData->get_data();
+                    switch ($singleShippingData['key']) {
+                        case '_pickup_location_name':
+                            $shippingDataArray['Pickup Location'] = $singleShippingData['value'];
+                            break;
+                        case '_pickup_date':
+                            $shippingDataArray['Pickup Date'] = $singleShippingData['value'];
+                            break;
+                        case '_pickup_location_address':
+                            $shippingDataArray['Pickup address'] = $singleShippingData['value'];
+                            break;
+                    }
                 }
             }
         }
@@ -172,8 +199,8 @@ class OrderController
     public static function getPastOrderDataAsJson($orders)
     {
         $days = [];
-        foreach ($orders as $singleOrder) {
 
+        foreach ($orders as $singleOrder) {
 
             if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
                 $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
@@ -189,7 +216,7 @@ class OrderController
                     ];
                 }
 
-                $days[$pickupDate]['orders'][] = $order->newOrderData();
+                $days[$pickupDate]['orders'][] = $order->newPastOrderData();
 
             }
         }
@@ -274,10 +301,12 @@ class OrderController
 
         $coupons = self::getCoupons($orderId);
 
+        $orderItems['address'] = $order->get_formatted_billing_address();
         $orderItems['pickup_date'] = $shipping['Pickup Date'];
         $orderItems['price'] = $order->get_total();
         $orderItems['coupons'] = $coupons;
         $orderItems['notes'] = $order->get_customer_note() ?: 'No note';
+        $orderItems['delivery'] = get_post_meta($orderId, 'deliveryType', true) == 'ship';
 
         $orderItems['orders'] = [];
         foreach ($order->get_items() as $itemKey => $item) {
@@ -390,7 +419,21 @@ class OrderController
             $order->update_status('wc-notcollected');
             $successMessage = 'This order has been marked as not collected';
         }
-
+        if ($statusNumber == 10) {
+            $shopNumber = get_post_meta($orderNumber, 'shop_id');
+            $finalPrice = get_post_meta($orderNumber, 'final_price');
+            if (!$shopNumber || !$finalPrice) {
+                $successMessage = 'Order not Updated, please check you have input the shop number and final price';
+            } else {
+                self::emailCustomerReadyForDelivery($order);
+                $order->update_status('wc-readyfordelivery');
+                $successMessage = 'Order has been marked as Ready for Delivery';
+            }
+        }
+        if ($statusNumber == 11) {
+            $order->update_status('wc-completed');
+            $successMessage = 'Order has been marked as completed';
+        }
         return $successMessage;
 
     }
@@ -441,6 +484,44 @@ class OrderController
 
     }
 
+    public function emailCustomerReadyForDelivery($order)
+    {
+        $shipping = self::getShippingDetails($order);
+        $order = new Order($order);
+
+        $shippingCost = '';
+        $totals = $order->get_order_item_totals();
+        foreach ( $totals as $total ) {
+            if($total['label'] == 'Shipping:') {
+                $shippingCost = $total['value'];
+            }
+
+        }
+
+        $finalPrice = $order->getFinalPrice();
+        $orderItems = [];
+
+        foreach ($order->getOrderItems() as $itemKey => $item) {
+            $newOrderItem = new OrderItem($item, $itemKey, $order->getOrderID());
+            $orderItems[] = $newOrderItem->newOrderItemData();
+        };
+
+        $date = strtotime($shipping['Pickup Date']);
+
+        $to = $order->getEmail();
+        $subject = 'Your Simon Howie order is now ready for delivery.';
+        $template = 'delivery';
+        ob_start();
+        include $this->pluginDirectoryPath . "/templates/emails/delivery.php";
+        $message = ob_get_clean();
+
+        $headers = ['Content-Type: text/html; charset=UTF-8'];
+
+        wp_mail($to, $subject, $message, $headers);
+
+    }
+
+
     public static function registerNewOrderStatus()
     {
         register_post_status('wc-awaiting', [
@@ -499,6 +580,15 @@ class OrderController
             'show_in_admin_status_list' => true,
             'label_count' => _n_noop('Collection Date Changed <span class="count">(%s)</span>', 'Collection Date Changed <span class="count">(%s)</span>'),
         ]);
+        register_post_status('wc-readyfordelivery', [
+            'label' => 'Ready for Delivery',
+            'public' => true,
+            'exclude_from_search' => false,
+            'show_in_admin_all_list' => true,
+            'show_in_admin_status_list' => true,
+            'label_count' => _n_noop('Ready for Delivery <span class="count">(%s)</span>', 'Ready for Delivery <span class="count">(%s)</span>'),
+        ]);
+
     }
 
     public static function getNotes($data)
@@ -641,13 +731,14 @@ class OrderController
                             'order' => $order->newOrderData(),
                             'coupons' => $coupons,
                             'shipping' => [
-                                $wcOrder->shipping_address_1,
-                                $wcOrder->shipping_address_2,
-                                $wcOrder->shipping_city,
-                                $wcOrder->shipping_postcode,
+                                $wcOrder->get_shipping_address_1(),
+                                $wcOrder->get_shipping_address_2(),
+                                $wcOrder->get_shipping_city(),
+                                $wcOrder->get_shipping_postcode(),
                             ],
                             'orderItems' => [],
                             'notes' => $wcOrder->get_customer_note() ?: 'No note',
+                            'delivery' => get_post_meta($orderId, 'deliveryType', true) == 'ship'
                         ];
                     }
 
@@ -664,12 +755,12 @@ class OrderController
         return $orderData;
     }
 
-    function dateSort($a, $b)
+    public function dateSort($a, $b)
     {
         return strtotime($a) - strtotime($b);
     }
 
-    function addToWoocommerceOrderStatus($orderStatuses)
+    public function addToWoocommerceOrderStatus($orderStatuses)
     {
         $newOrderStatuses = [];
         foreach ($orderStatuses as $key => $status) {
@@ -682,6 +773,8 @@ class OrderController
                 $newOrderStatuses['wc-collected'] = 'Collected';
                 $newOrderStatuses['wc-notcollected'] = 'Not Collected';
                 $newOrderStatuses['wc-datechanged'] = 'Collection Date Changed';
+                $newOrderStatuses['wc-readyfordelivery'] = 'Ready for Delivery';
+                $newOrderStatuses['wc-completed'] = 'Completed';
             }
         }
         return $newOrderStatuses;
